from .actor_job_base_client import ActorJobBaseClient
from .base_client import BaseClient
from .resource_client import ResourceClient
from .resource_collection_client import ResourceCollectionClient

__all__ = [
    'ActorJobBaseClient',
    'BaseClient',
    'ResourceClient',
    'ResourceCollectionClient',
]



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Dict, Optional

from ..._http_client import _HTTPClient
from ..._utils import _to_safe_id

# Conditional import only executed when type checking, otherwise we'd get circular dependency issues
if TYPE_CHECKING:
    from ...client import ApifyClient


class BaseClient:
    """Base class for sub-clients."""

    def __init__(
        self,
        *,
        base_url: str,
        root_client: ApifyClient,
        http_client: _HTTPClient,
        resource_id: Optional[str] = None,
        resource_path: str,
        params: Optional[Dict] = None,
    ) -> None:
        """Initialize the sub-client.

        Args:
            base_url (str): Base URL of the API server
            root_client (ApifyClient): The ApifyClient instance under which this resource client exists
            http_client (_HTTPClient): The _HTTPClient instance to be used in this client
            resource_id (str): ID of the manipulated resource, in case of a single-resource client
            resource_path (str): Path to the resource's endpoint on the API server
            params (dict): Parameters to include in all requests from this client
        """
        if resource_path.endswith('/'):
            raise ValueError('resource_path must not end with "/"')

        self.base_url = base_url
        self.root_client = root_client
        self.http_client = http_client
        self.params = params or {}
        self.resource_path = resource_path
        self.resource_id = resource_id
        self.url = f'{self.base_url}/{self.resource_path}'
        if self.resource_id is not None:
            self.safe_id = _to_safe_id(self.resource_id)
            self.url = f'{self.url}/{self.safe_id}'

    def _url(self, path: Optional[str] = None) -> str:
        if path is not None:
            return f'{self.url}/{path}'
        return self.url

    def _params(self, **kwargs: Any) -> Dict:
        return {
            **self.params,
            **kwargs,
        }

    def _sub_resource_init_options(self, **kwargs: Any) -> Dict:
        options = {
            'base_url': self.url,
            'http_client': self.http_client,
            'params': self.params,
            'root_client': self.root_client,
        }

        return {
            **options,
            **kwargs,
        }



import pathlib

from setuptools import find_packages, setup

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / 'README.md').read_text(encoding='utf-8')

version_file = (here / 'src/apify_client/_version.py').read_text(encoding='utf-8')
version = None
for line in version_file.splitlines():
    if line.startswith('__version__'):
        delim = '"' if '"' in line else "'"
        version = line.split(delim)[1]
        break
else:
    raise RuntimeError("Unable to find version string.")

setup(
    name='apify_client',
    version=version,

    author="Apify Technologies s.r.o.",
    author_email="support@apify.com",
    url="https://github.com/apify/apify-client-python",
    project_urls={
        'Documentation': 'https://docs.apify.com/apify-client-python',
        'Source': 'https://github.com/apify/apify-client-python',
        'Issue tracker': 'https://github.com/apify/apify-client-python/issues',
        'Apify Homepage': 'https://apify.com',
    },
    license='Apache Software License',
    license_files=['LICENSE'],

    description='Apify API client for Python',
    long_description=long_description,
    long_description_content_type='text/markdown',

    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
    ],
    keywords='apify, api, client, scraping, automation',

    package_dir={'': 'src'},
    packages=find_packages(where='src'),
    python_requires='>=3.7',
    install_requires=['requests ~= 2.26.0'],
    extras_require={
        'dev': [
            'autopep8 ~= 1.5.7',
            'flake8 ~= 3.9.2',
            'flake8-commas ~= 2.0.0',
            'flake8-docstrings ~= 1.6.0',
            'flake8-isort ~= 4.0.0',
            'flake8-quotes ~= 3.2.0',
            'isort ~= 5.9.3',
            'mypy ~= 0.910',
            'pep8-naming ~= 0.11.1',
            'pytest ~= 6.2.2',
            'sphinx ~= 4.1.2',
            'sphinx-autodoc-typehints ~= 1.12.0',
            'sphinx-markdown-builder ~= 0.5.4',
            'types-requests ~= 2.25.2',
        ],
    },
)
